@@ -178,6 +178,14 @@ class StellarCoreHandler(BaseHTTPRequestHandler):
                                     labels=tuple(zip(self.label_names+['quantile'], self.labels+[0.99])),
                                     value=lib.duration_to_seconds(metrics[k]['99%'], metrics[k]['duration_unit']),
                                     )
+                # Newer versions of core report a '100%' quantile which is the max
+                # sample over the recent sampling period (not all-time).
+                if '100%' in metrics[k]:
+                    self.registry.Gauge(metric_name, 'libmedida metric type: ' + metrics[k]['type'],
+                                        labels=tuple(zip(self.label_names+['quantile'], self.labels+[1.0])),
+                                        value=lib.duration_to_seconds(metrics[k]['100%'], metrics[k]['duration_unit']),
+                                        )
+
             elif metrics[k]['type'] == 'histogram':
                 if 'count' not in metrics[k]:
                     # Stellar-core version too old, we don't have required data
@@ -196,6 +204,14 @@ class StellarCoreHandler(BaseHTTPRequestHandler):
                                     labels=tuple(zip(self.label_names+['quantile'], self.labels+[0.99])),
                                     value=metrics[k]['99%'],
                                     )
+                # Newer versions of core report a '100%' quantile which is the max
+                # sample over the recent sampling period (not all-time).
+                if '100%' in metrics[k]:
+                    self.registry.Gauge(metric_name, 'libmedida metric type: ' + metrics[k]['type'],
+                                        labels=tuple(zip(self.label_names+['quantile'], self.labels+[1.0])),
+                                        value=metrics[k]['100%'],
+                                        )
+
             elif metrics[k]['type'] == 'counter':
                 # we have a counter, this is a Prometheus Gauge
                 self.registry.Gauge(metric_name, 'libmedida metric type: ' + metrics[k]['type'],
@@ -254,19 +270,29 @@ class StellarCoreHandler(BaseHTTPRequestHandler):
             return
 
         for metric in self.quorum_metrics:
-            self.registry.Gauge('stellar_core_quorum_{}'.format(metric),
-                                'Stellar core quorum metric: {}'.format(metric),
-                                tmp[metric]
-                                )
-        for metric in self.quorum_phase_metrics:
-            if tmp['phase'].lower() == metric:
-                value = 1
-            else:
-                value = 0
-            self.registry.Gauge('stellar_core_quorum_phase_{}'.format(metric),
-                                'Stellar core quorum phase {}'.format(metric),
-                                value=value,
-                                )
+            try:
+
+                self.registry.Gauge('stellar_core_quorum_{}'.format(metric),
+                                    'Stellar core quorum metric: {}'.format(metric),
+                                    tmp[metric]
+                                    )
+            except KeyError as e:
+                self.log_message('Unable to find metric in quorum qset: {}. This is probably fine and will fix itself as stellar-core joins the quorum, or core is running cli catchup'.format(metric))
+
+        try:
+
+            for metric in self.quorum_phase_metrics:
+                if tmp['phase'].lower() == metric:
+                    value = 1
+                else:
+                    value = 0
+                self.registry.Gauge('stellar_core_quorum_phase_{}'.format(metric),
+                                    'Stellar core quorum phase {}'.format(metric),
+                                    value=value,
+                                    )
+        except KeyError as e:
+                self.log_message('Unable to find phase in quorum qset. This is probably fine and will fix itself as stellar-core joins the quorum, or core is running cli catchup')
+
         # Versions >=11.2.0 expose more info about quorum
         if 'transitive' in info['quorum']:
             if info['quorum']['transitive']['intersection']:
